@@ -20,14 +20,13 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: __init__.py 20356 2012-09-10 11:25:40Z bmcage $
 
 """
 Package providing filter rules for GRAMPS.
 """
 
-from Filters.Rules._HasCitationBase import HasCitationBase as HasCitation
-
+from _HasCitation import HasCitation
 from _AllCitations import AllCitations
 from _ChangedSince import ChangedSince
 from _CitationPrivate import CitationPrivate
@@ -45,6 +44,7 @@ from _MatchesSourceFilter import MatchesSourceFilter
 from _RegExpIdOf import RegExpIdOf
 
 editor_rule_list = [
+    HasCitation,
     AllCitations,
     ChangedSince,
     CitationPrivate,
