@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _HasData.py 21941 2013-04-10 13:21:14Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -50,8 +50,8 @@ class HasData(Rule):
     description = _("Matches events with data of a particular value")
     category    = _('General filters')
     
-    def __init__(self, list):
-        Rule.__init__(self, list)
+    def __init__(self, list, use_regex=False):
+        Rule.__init__(self, list, use_regex)
 
         self.event_type = self.list[0]
         self.date = self.list[1]
