@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _HasCitation.py 20270 2012-08-27 09:21:10Z bmcage $
 
 """
 Filter rule to match family with a particular citation.
@@ -52,10 +52,3 @@ class HasCitation(HasCitationBase):
     name        =  _('Family with the <citation>')
     description = _("Matches families with a citation of a particular "
                     "value")
-    
-    def apply(self, dbase, family):
-        for citation_handle in family.get_citation_list():
-            citation = dbase.get_citation_from_handle(citation_handle)
-            if HasCitationBase.apply(self, dbase, citation):
-                return True
-        return False
