@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: __init__.py 20270 2012-08-27 09:21:10Z bmcage $
 
 """
 Package providing filter rules for GRAMPS.
@@ -48,6 +48,7 @@ from _HasCitation import HasCitation
 from _FamilyPrivate import FamilyPrivate
 from _HasAttribute import HasAttribute
 from _HasEvent import HasEvent
+from _HasSourceOf import HasSourceOf
 from _IsBookmarked import IsBookmarked
 from _MatchesFilter import MatchesFilter
 from _MatchesSourceConfidence import MatchesSourceConfidence
@@ -72,6 +73,7 @@ editor_rule_list = [
     HasNoteMatchingSubstringOf,
     HasReferenceCountOf,
     HasSourceCount,
+    HasSourceOf,
     HasCitation, 
     FamilyPrivate,
     HasEvent,
