@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: __init__.py 20270 2012-08-27 09:21:10Z bmcage $
 
 """
 Package providing filter rules for GRAMPS.
@@ -27,11 +27,15 @@ Package providing filter rules for GRAMPS.
 from _AllMedia import AllMedia
 from _HasIdOf import HasIdOf
 from _RegExpIdOf import RegExpIdOf
+from _HasCitation import HasCitation
 from _HasNoteRegexp import HasNoteRegexp
 from _HasNoteMatchingSubstringOf import HasNoteMatchingSubstringOf
 from _HasReferenceCountOf import HasReferenceCountOf
+from _HasSourceCount import HasSourceCount
+from _HasSourceOf import HasSourceOf
 from _MediaPrivate import MediaPrivate
 from _MatchesFilter import MatchesFilter
+from _MatchesSourceConfidence import MatchesSourceConfidence
 from _HasMedia import HasMedia
 from _HasAttribute import HasAttribute
 from _ChangedSince import ChangedSince
@@ -41,11 +45,15 @@ editor_rule_list = [
     AllMedia,
     HasIdOf,
     RegExpIdOf,
+    HasCitation,
     HasNoteRegexp,
     HasNoteMatchingSubstringOf,
     HasReferenceCountOf,
+    HasSourceCount,
+    HasSourceOf,
     MediaPrivate,
     MatchesFilter,
+    MatchesSourceConfidence,
     HasAttribute,
     ChangedSince,
     HasTag,
