@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _MatchesRegexpOf.py 21974 2013-04-13 14:11:20Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -47,8 +47,8 @@ class MatchesRegexpOf(Rule):
                     "which matches a regular expression")
     category    = _('General filters')
 
-    def __init__(self, list):
-        Rule.__init__(self, list)
+    def __init__(self, list, use_regex=False):
+        Rule.__init__(self, list, use_regex)
         
         try:
             self.match = re.compile(list[0], re.I|re.U|re.L)
@@ -58,6 +58,6 @@ class MatchesRegexpOf(Rule):
     def apply(self, db, note):
         """ Apply the filter """
         text = note.get()
-        if self.match.match(text) is not None:
+        if self.match.search(text) is not None:
             return True
         return False
