@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _HasBirth.py 21941 2013-04-10 13:21:14Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -49,8 +49,8 @@ class HasBirth(Rule):
     description = _("Matches people with birth data of a particular value")
     category    = _('Event filters')
     
-    def __init__(self,list):
-        Rule.__init__(self,list)
+    def __init__(self, list, use_regex=False):
+        Rule.__init__(self, list, use_regex)
         if self.list[0]:
             self.date = DateHandler.parser.parse(self.list[0])
         else:
