@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasNameOf.py 20393 2012-09-15 13:29:50Z romjerome $
+# $Id: _HasNameOf.py 21974 2013-04-13 14:11:20Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -110,31 +110,31 @@ class HasNameOf(Rule):
                 valpatr = 1
             if self.regular_expression:
                 try:
-                    if self.firstn and not re.match(self.firstn, name.get_first_name(), re.I|re.U|re.L):
+                    if self.firstn and not re.search(self.firstn, name.get_first_name(), re.I|re.U|re.L):
                         val = 0
-                    elif self.lastn and not re.match(self.lastn, name.get_surname(), re.I|re.U|re.L):
+                    elif self.lastn and not re.search(self.lastn, name.get_surname(), re.I|re.U|re.L):
                         val = 0
-                    elif self.suffix and not re.match(self.suffix, name.get_suffix(), re.I|re.U|re.L):
+                    elif self.suffix and not re.search(self.suffix, name.get_suffix(), re.I|re.U|re.L):
                         val = 0
-                    elif self.title and not re.match(self.title, name.get_title(), re.I|re.U|re.L):
+                    elif self.title and not re.search(self.title, name.get_title(), re.I|re.U|re.L):
                         val = 0
-                    elif self.calln and not re.match(self.calln, name.get_call_name(), re.I|re.U|re.L):
+                    elif self.calln and not re.search(self.calln, name.get_call_name(), re.I|re.U|re.L):
                         val = 0
-                    elif self.nick and not re.match(self.nick, name.get_nick_name(), re.I|re.U|re.L):
+                    elif self.nick and not re.search(self.nick, name.get_nick_name(), re.I|re.U|re.L):
                         val = 0
-                    elif self.famnick and not re.match(self.famnick, name.get_family_nick_name(), re.I|re.U|re.L):
+                    elif self.famnick and not re.search(self.famnick, name.get_family_nick_name(), re.I|re.U|re.L):
                         val = 0
                     else:
                         #obtain surnames
                         for surn in name.get_surname_list():
-                            if self.prefix and re.match(self.prefix, surn.get_prefix(), re.I|re.U|re.L):
+                            if self.prefix and re.search(self.prefix, surn.get_prefix(), re.I|re.U|re.L):
                                 valpref = 1
-                            if self.surn and re.match(self.surn, surn.get_surname(), re.I|re.U|re.L):
+                            if self.surn and re.search(self.surn, surn.get_surname(), re.I|re.U|re.L):
                                 valsurn = 1
-                            if self.con and re.match(self.con, surn.get_connector(), re.I|re.U|re.L):
+                            if self.con and re.search(self.con, surn.get_connector(), re.I|re.U|re.L):
                                 valcon = 1
                             if self.patr and surn.get_origintype().value == NameOriginType.PATRONYMIC \
-                                    and re.match(self.patr, surn.get_surname(), re.I|re.U|re.L):
+                                    and re.search(self.patr, surn.get_surname(), re.I|re.U|re.L):
                                 valpatr = 1
                 except re.error:
                     #indicate error in the pattern by matching everyone
