@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _HasTextMatchingRegexpOf.py 21941 2013-04-10 13:21:14Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -41,8 +41,8 @@ class HasTextMatchingRegexpOf(HasTextMatchingSubstringOf):
     parameter.
     
     """
-    def __init__(self,list):
-        HasTextMatchingSubstringOf.__init__(self,list)
+    def __init__(self, list, use_regex=False):
+        HasTextMatchingSubstringOf.__init__(self, list, use_regex)
 
     def prepare(self,db):
         self.db = db
