@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _RegExpName.py 20364 2012-09-11 09:28:55Z bmcage $
+# $Id: _RegExpName.py 21974 2013-04-13 14:11:20Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -49,8 +49,8 @@ class RegExpName(Rule):
     description = _("Matches people's names with a specified regular expression")
     category    = _('General filters')
 
-    def __init__(self, list):
-        Rule.__init__(self, list)
+    def __init__(self, list, use_regex=False):
+        Rule.__init__(self, list, use_regex)
         
         try:
             self.match = re.compile(list[0],re.I|re.U|re.L)
@@ -62,7 +62,7 @@ class RegExpName(Rule):
         for name in [person.get_primary_name()] + person.get_alternate_names():
             for field in [name.first_name, name.get_surname(), name.suffix, 
                           name.title, name.nick, name.famnick, name.call]:
-                if self.match.match(field):
+                if self.match.search(field):
                     return True
         else:
             return False
