@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _HasNoteRegexBase.py 21974 2013-04-13 14:11:20Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -47,8 +47,8 @@ class HasNoteRegexBase(Rule):
                     "matching a regular expression")
     category    = _('General filters')
 
-    def __init__(self, list):
-        Rule.__init__(self, list)
+    def __init__(self, list, use_regex=False):
+        Rule.__init__(self, list, use_regex)
         
         try:
             self.match = re.compile(list[0],re.I|re.U|re.L)
@@ -60,6 +60,6 @@ class HasNoteRegexBase(Rule):
         for notehandle in notelist:
             note = db.get_note_from_handle(notehandle)
             n = note.get()
-            if self.match.match(n) is not None:
+            if self.match.search(n) is not None:
                 return True
         return False
