@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _RegExpIdBase.py 21974 2013-04-13 14:11:20Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -51,8 +51,8 @@ class RegExpIdBase(Rule):
                     "the regular expression")
     category    = _('General filters')
 
-    def __init__(self, list):
-        Rule.__init__(self, list)
+    def __init__(self, list, use_regex=False):
+        Rule.__init__(self, list, use_regex)
         
         try:
             self.match = re.compile(list[0], re.I|re.U|re.L)
@@ -60,4 +60,4 @@ class RegExpIdBase(Rule):
             self.match = re.compile('')
 
     def apply(self, db, obj):
-        return self.match.match(obj.gramps_id) is not None
+        return self.match.search(obj.gramps_id) is not None
