@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _FilterList.py 21933 2013-04-09 13:51:07Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -135,8 +135,8 @@ class FilterList(object):
                     f.write(' comment="%s"' % self.fix(comment))
                 f.write('>\n')
                 for rule in the_filter.get_rules():
-                    f.write('    <rule class="%s">\n'
-                            % rule.__class__.__name__)
+                    f.write('    <rule class="%s" use_regex="%s">\n'
+                            % (rule.__class__.__name__, rule.use_regex))
                     for value in rule.values():
                         f.write('      <arg value="%s"/>\n' % self.fix(value))
                     f.write('    </rule>\n')
