@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: TransUtils.py 20013 2012-07-16 22:54:43Z kulath $
+# $Id: TransUtils.py 20675 2012-11-17 21:28:51Z paul-franklin $
 
 """
 Provide translation assistance
@@ -49,7 +49,10 @@ from constfunc import mac
 #
 #-------------------------------------------------------------------------
 if "GRAMPSI18N" in os.environ:
-    LOCALEDIR = os.environ["GRAMPSI18N"]
+    if os.path.exists(os.environ["GRAMPSI18N"]):
+        LOCALEDIR = os.environ["GRAMPSI18N"]
+    else:
+        LOCALEDIR = None
 elif os.path.exists( os.path.join(const.ROOT_DIR, "lang") ):
     LOCALEDIR = os.path.join(const.ROOT_DIR, "lang")
 elif os.path.exists(os.path.join(const.PREFIXDIR, "share/locale")):
@@ -219,8 +222,8 @@ def setup_windows_gettext():
         return
 
     # No complete/working translation found
-    logging.warning("Translation might not be complete/not working for",\
-           locale.getlocale()[0])
+    logging.warning("Translation might not be complete, "
+                    "not working for your locale")
     
 
 def get_localedomain():
