@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: Utils.py 22149 2013-05-03 06:55:58Z romjerome $
 
 """
 Non GUI/GTK related utility functions
@@ -277,29 +277,81 @@ def encodingdefs():
     
     conv_unicode_tosrtkey_ongtk:  convert a unicode object to sortkey usable 
     string when gtk is loaded or utf-8 is default python encoding
+    
+    COLLATE_LANG: Language and sub-locale used for collation
     """
     pass
 
-if constfunc.win():
-    # python encoding is ascii, but C functions need to receive the 
-    # windows codeset, so convert over to it
-    conv_utf8_tosrtkey = lambda x: locale.strxfrm(x.decode("utf-8").encode(
-                                                        codeset))
-    conv_unicode_tosrtkey = lambda x: locale.strxfrm(x.encode(codeset))
-    #when gtk is imported the python defaultencoding is utf-8, 
-    #so no need to specify it
-    conv_utf8_tosrtkey_ongtk = lambda x: locale.strxfrm(unicode(x).encode(
-                                                                    codeset))
-    conv_unicode_tosrtkey_ongtk = lambda x: locale.strxfrm(x.encode(codeset,'replace'))
-else:
-    # on unix C functions need to receive utf-8. Default conversion would
-    # use ascii, so it is needed to be explicit about the resulting encoding 
-    conv_utf8_tosrtkey = lambda x: locale.strxfrm(x)
-    conv_unicode_tosrtkey = lambda x: locale.strxfrm(x.encode("utf-8"))
-    # when gtk loaded, default encoding (sys.getdefaultencoding ) is utf-8,
-    # so default conversion happens with utf-8 
-    conv_utf8_tosrtkey_ongtk = lambda x:  locale.strxfrm(x)
-    conv_unicode_tosrtkey_ongtk = lambda x:  locale.strxfrm(x)
+try:
+    import PyICU
+    if os.environ.has_key("LC_COLLATE"):
+        collation = os.environ['LC_COLLATE']
+    else:
+        collation = os.environ["LANG"]
+    language_and_country = collation.rsplit('.', 1)[0]
+    if language_and_country in PyICU.Collator.getAvailableLocales().keys():
+        COLLATE_LANG = language_and_country
+    else:
+        language = collation.rsplit('_', 1)[0]
+        if language in PyICU.Collator.getAvailableLocales().keys():
+            LOG.warn(_('The language and country combination "%s" '
+                       'is not supported by ICU, '
+                       'but language %s is supported and will be used' %
+                       (language_and_country, language)))
+            COLLATE_LANG = language
+        else:
+            LOG.warn(_('Neither the language and country combination '
+                       '"%s" nor language %s is supported by ICU: using en_GB' % 
+                       (language_and_country, language)))
+            COLLATE_LANG = "en_GB"
+    
+    collator = PyICU.Collator.createInstance(PyICU.Locale(COLLATE_LANG))
+    # on ICU, the functions need to receive unicode
+    conv_utf8_tosrtkey = lambda x: collator.getCollationKey(
+                                        x.decode("UTF-8")).getByteArray()
+    conv_unicode_tosrtkey = lambda x: collator.getCollationKey(
+                                        x).getByteArray()
+    conv_utf8_tosrtkey_ongtk = lambda x: collator.getCollationKey(
+                                        x.decode("UTF-8")).getByteArray()
+    conv_unicode_tosrtkey_ongtk = lambda x: collator.getCollationKey(
+                                    x).getByteArray()
+except:
+    LOG.warn(_("PyICU not available: sorting may be incorrect"))
+    COLLATE_LANG = locale.getlocale()[0]
+    if constfunc.win():
+        # python encoding is ascii, but C functions need to receive the 
+        # windows codeset, so convert over to it
+        conv_utf8_tosrtkey = lambda x: locale.strxfrm(x.decode("utf-8").encode(
+                                                            codeset))
+        conv_unicode_tosrtkey = lambda x: locale.strxfrm(x.encode(codeset))
+        #when gtk is imported the python defaultencoding is utf-8, 
+        #so no need to specify it
+        conv_utf8_tosrtkey_ongtk = lambda x: locale.strxfrm(unicode(x).encode(
+                                                                        codeset))
+        conv_unicode_tosrtkey_ongtk = lambda x: locale.strxfrm(x.encode(codeset,'replace'))
+    elif constfunc.mac():
+        # On mac strxfrm seems to be broken such that better results are
+        # obtained by applying strxfrm to each character individually, rather
+        # than applying the function to the whole string. See in particular
+        # greek names at bug 5645
+        
+        # on mac C functions need to receive utf-8. Default conversion would
+        # use ascii, so it is needed to be explicit about the resulting encoding 
+        conv_utf8_tosrtkey = lambda x: map(locale.strxfrm, x)
+        conv_unicode_tosrtkey = lambda x: map(locale.strxfrm, x.encode("utf-8"))
+        # when gtk loaded, default encoding (sys.getdefaultencoding ) is utf-8,
+        # so default conversion happens with utf-8 
+        conv_utf8_tosrtkey_ongtk = lambda x:  map(locale.strxfrm, x)
+        conv_unicode_tosrtkey_ongtk = lambda x:  map(locale.strxfrm, x.encode("utf-8"))
+    else:
+        # on unix C functions need to receive utf-8. Default conversion would
+        # use ascii, so it is needed to be explicit about the resulting encoding 
+        conv_utf8_tosrtkey = lambda x: locale.strxfrm(x)
+        conv_unicode_tosrtkey = lambda x: locale.strxfrm(x.encode("utf-8"))
+        # when gtk loaded, default encoding (sys.getdefaultencoding ) is utf-8,
+        # so default conversion happens with utf-8 
+        conv_utf8_tosrtkey_ongtk = lambda x:  locale.strxfrm(x)
+        conv_unicode_tosrtkey_ongtk = lambda x:  locale.strxfrm(x.encode("utf-8"))
 
 #-------------------------------------------------------------------------
 #
@@ -667,13 +719,25 @@ class ProbablyAlive(object):
                     if mother_handle == person.handle and father_handle:
                         father = self.db.get_person_from_handle(father_handle)
                         date1, date2, explain, other = self.probably_alive_range(father, is_spouse=True)
-                        if date1 and date2:
-                            return date1, date2, _("a spouse, ") + explain, other
+                        if date1 and date1.get_year() != 0:
+                            return (gen.lib.Date().copy_ymd(date1.get_year() - self.AVG_GENERATION_GAP),
+                                    gen.lib.Date().copy_ymd(date1.get_year() - self.AVG_GENERATION_GAP + self.MAX_AGE_PROB_ALIVE),
+                                    _("a spouse, ") + explain, other)
+                        elif date2 and date2.get_year() != 0:
+                            return (gen.lib.Date().copy_ymd(date2.get_year() + self.AVG_GENERATION_GAP - self.MAX_AGE_PROB_ALIVE),
+                                    gen.lib.Date().copy_ymd(date2.get_year() + self.AVG_GENERATION_GAP),
+                                    _("a spouse, ") + explain, other)
                     elif father_handle == person.handle and mother_handle:
                         mother = self.db.get_person_from_handle(mother_handle)
                         date1, date2, explain, other = self.probably_alive_range(mother, is_spouse=True)
-                        if date1 and date2:
-                            return date1, date2, _("a spouse, ") + explain, other
+                        if date1 and date1.get_year() != 0:
+                            return (gen.lib.Date().copy_ymd(date1.get_year() - self.AVG_GENERATION_GAP),
+                                    gen.lib.Date().copy_ymd(date1.get_year() - self.AVG_GENERATION_GAP + self.MAX_AGE_PROB_ALIVE),
+                                    _("a spouse, ") + explain, other)
+                        elif date2 and date2.get_year() != 0:
+                            return (gen.lib.Date().copy_ymd(date2.get_year() + self.AVG_GENERATION_GAP - self.MAX_AGE_PROB_ALIVE),
+                                    gen.lib.Date().copy_ymd(date2.get_year() + self.AVG_GENERATION_GAP),
+                                    _("a spouse, ") + explain, other)
                     # Let's check the family events and see if we find something
                     for ref in family.get_event_ref_list():
                         if ref:
