@@ -25,7 +25,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: arghandler.py 20445 2012-09-25 16:51:45Z ldnp $
+# $Id: arghandler.py 21850 2013-04-02 16:01:50Z kulath $
 
 """
 Module responsible for handling the command line arguments for GRAMPS.
@@ -162,6 +162,7 @@ class ArgHandler(object):
             self.actions = parser.actions
             self.list = parser.list
             self.list_more = parser.list_more
+            self.list_table = parser.list_table
         self.open_gui = parser.open_gui
         self.imp_db_path = None
         self.dbman = CLIDbManager(self.dbstate)
@@ -369,12 +370,8 @@ class ArgHandler(object):
                 if not self.check_db(db_path, self.force_unlock):
                     sys.exit(0)
                 # Add the file to the recent items
-                path = os.path.join(db_path, "name.txt")
-                try:
-                    ifile = open(path)
-                    title = ifile.readline().strip()
-                    ifile.close()
-                except:
+                title = self.dbstate.db.get_dbname()
+                if not title:
                     title = db_path
                 RecentFiles.recent_files(db_path, title)
                 self.open = db_path
@@ -423,6 +420,27 @@ class ArgHandler(object):
                                encode(sys.getfilesystemencoding())
             sys.exit(0)
            
+        if self.list_table:
+            print _('Gramps Family Trees:').encode(sys.getfilesystemencoding())
+            summary_list = self.dbman.family_tree_summary()
+            print _("Family Tree").encode(sys.getfilesystemencoding()),
+            for key in sorted(summary_list[0]):
+                if key !=  _("Family tree"):
+                    print "\t ",
+                    print key.encode(sys.getfilesystemencoding()),
+            print
+            for summary in sorted(summary_list,
+                                  key=lambda sum: sum[_("Family tree")].lower()):
+                print '"%s"'.\
+                        encode(sys.getfilesystemencoding()) % summary[_("Family tree")],
+                for item in sorted(summary):
+                    if item != _("Family tree"):
+                        print "\t ",
+                        print ('"%s"' % summary[item]).\
+                               encode(sys.getfilesystemencoding()),
+                print
+            sys.exit(0)
+
         self.__open_action()
         self.__import_action()
             
