@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: clidbman.py 20455 2012-09-27 09:18:34Z bmcage $
+# $Id: clidbman.py 21850 2013-04-02 16:01:50Z kulath $
 
 """
 Provide the management of databases from CLI. This includes opening, renaming,
@@ -46,6 +46,8 @@ from gen.ggettext import gettext as _
 #-------------------------------------------------------------------------
 import logging
 LOG = logging.getLogger(".clidbman")
+from gen.db.dbconst import DBLOGNAME
+_LOG = logging.getLogger(DBLOGNAME)
 
 #-------------------------------------------------------------------------
 #
@@ -127,67 +129,91 @@ class CLIDbManager(object):
         """
         pass
 
-    def get_dbdir_summary(self, file_name):
+    def get_dbdir_summary(self, dirpath, name):
         """
-        Returns (people_count, version_number) of current DB.
-        Returns ("Unknown", "Unknown") if invalid DB or other error.
+        Returns (people_count, bsddb_version, schema_version) of
+        current DB.
+        Returns ("Unknown", "Unknown", "Unknown") if invalid DB or other error.
         """
         if config.get('preferences.use-bsddb3'):
             from bsddb3 import dbshelve, db
         else:
             from bsddb import dbshelve, db
+
         from gen.db import META, PERSON_TBL
+        from  gen.db.dbconst import BDBVERSFN
+
+        bdbversion_file = os.path.join(dirpath, BDBVERSFN)
+        if os.path.isfile(bdbversion_file):
+            vers_file = open(bdbversion_file)
+            bsddb_version = vers_file.readline().strip()
+        else:
+            return "Unknown", "Unknown", "Unknown"
+        
+        current_bsddb_version = str(db.version())
+        if bsddb_version != current_bsddb_version:
+            return "Unknown", bsddb_version, "Unknown"
+        
         env = db.DBEnv()
         flags = db.DB_CREATE | db.DB_PRIVATE |\
-            db.DB_INIT_MPOOL | db.DB_INIT_LOCK |\
-            db.DB_INIT_LOG | db.DB_INIT_TXN | db.DB_THREAD
+            db.DB_INIT_MPOOL |\
+            db.DB_INIT_LOG | db.DB_INIT_TXN
         try:
-            env.open(file_name, flags)
-        except:
-            return "Unknown", "Unknown"
+            env.open(dirpath, flags)
+        except Exception as msg:
+            LOG.warning("Error opening db environment for '%s': %s" %
+                        (name, str(msg)))
+            try:
+                env.close()
+            except Exception as msg:
+                LOG.warning("Error closing db environment for '%s': %s" %
+                        (name, str(msg)))
+            return "Unknown", bsddb_version, "Unknown"
         dbmap1 = dbshelve.DBShelf(env)
-        fname = os.path.join(file_name, META + ".db")
+        fname = os.path.join(dirpath, META + ".db")
         try:
             dbmap1.open(fname, META, db.DB_HASH, db.DB_RDONLY)
         except:
-            return "Unknown", "Unknown"
-        version = dbmap1.get('version', default=None)
+            env.close()
+            return "Unknown", bsddb_version, "Unknown"
+        schema_version = dbmap1.get('version', default=None)
         dbmap1.close()
         dbmap2 = dbshelve.DBShelf(env)
-        fname = os.path.join(file_name, PERSON_TBL + ".db")
+        fname = os.path.join(dirpath, PERSON_TBL + ".db")
         try:
             dbmap2.open(fname, PERSON_TBL, db.DB_HASH, db.DB_RDONLY)
         except:
             env.close()
-            return "Unknown", "Unknown"
+            return "Unknown", bsddb_version, schema_version
         count = len(dbmap2)
         dbmap2.close()
         env.close()
-        return (count, version)
+        return (count, bsddb_version, schema_version)
 
     def family_tree_summary(self):
         """
         Return a list of dictionaries of the known family trees.
         """
         # make the default directory if it does not exist
-        list = []
+        summary_list = []
         for item in self.current_names:
             (name, dirpath, path_name, last, 
              tval, enable, stock_id) = item
-            count, version = self.get_dbdir_summary(dirpath)
+            count, bsddb_version, schema_version = self.get_dbdir_summary(dirpath, name)
             retval = {}
             retval[_("Number of people")] = count
             if enable:
                 retval[_("Locked?")] = _("yes")
             else:
                 retval[_("Locked?")] = _("no")
-            retval[_("DB version")] = version
+            retval[_("Bsddb version")] = bsddb_version
+            retval[_("Schema version")] = schema_version
             retval[_("Family tree")] = name.encode(sys.getfilesystemencoding())
             retval[_("Path")] = dirpath
             retval[_("Last accessed")] = time.strftime('%x %X', 
                                                     time.localtime(tval))
-            list.append( retval )
-        return list
+            summary_list.append( retval )
+        return summary_list
 
     def _populate_cli(self):
         """ Get the list of current names in the database dir
@@ -203,7 +229,9 @@ class CLIDbManager(object):
                 dirpath = os.path.join(dbdir, dpath)
                 path_name = os.path.join(dirpath, NAME_FILE)
                 if os.path.isfile(path_name):
-                    name = file(path_name).readline().strip()
+                    f = open(path_name)
+                    name = f.readline().strip()
+                    f.close()
 
                     (tval, last) = time_val(dirpath)
                     (enable, stock_id) = self.icon_values(dirpath, self.active, 
@@ -319,6 +347,11 @@ class CLIDbManager(object):
                 self.__start_cursor(_("Importing data..."))
                 dbclass = gen.db.DbBsddb
                 dbase = dbclass()
+                from  gen.db.dbconst import BDBVERSFN
+                versionpath = os.path.join(name, BDBVERSFN)
+                _LOG.debug("Write bsddb version %s" % str(dbase.version()))
+                with open(versionpath, "w") as version_file:
+                    version_file.write(str(dbase.version()))
                 dbase.load(new_path, callback)
     
                 import_function = plugin.get_import_function()
