@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: const.py.in 20464 2012-09-29 16:32:39Z ldnp $
+# $Id: const.py.in 21826 2013-03-31 22:08:17Z kulath $
 
 """
 Provides constants for other modules
@@ -42,11 +42,11 @@ from gen.ggettext import sgettext as _
 #
 #-------------------------------------------------------------------------
 PROGRAM_NAME   = "Gramps"
-if "3.4.2-1" == "@" + "VERSIONSTRING" + "@":
-    VERSION        = "3.4.2"
+if "3.4.4-1" == "@" + "VERSIONSTRING" + "@":
+    VERSION        = "3.4.4"
 else:
-    VERSION        = "3.4.2-1"
-VERSION_TUPLE  = (3, 4, 2)
+    VERSION        = "3.4.4-1"
+VERSION_TUPLE  = (3, 4, 4)
 
 #-------------------------------------------------------------------------
 #
@@ -199,7 +199,7 @@ else:
 #
 #-------------------------------------------------------------------------
 COPYRIGHT_MSG  = u"\u00A9 2001-2006 Donald N. Allingham\n" \
-                 u"\u00A9 2007-2012 The Gramps Developers"
+                 u"\u00A9 2007-2013 The Gramps Developers"
 COMMENTS       = _("Gramps (Genealogical Research and Analysis "
                    "Management Programming System) is a personal "
                    "genealogy program.")
@@ -301,6 +301,6 @@ LONGOPTS = [
     "qml",
 ]
 
-SHORTOPTS = "O:C:i:e:f:a:p:d:c:lLhuv?s"
+SHORTOPTS = "O:C:i:e:f:a:p:d:c:lLthuv?s"
 
 GRAMPS_UUID =  uuid.UUID('516cd010-5a41-470f-99f8-eb22f1098ad6')
