@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: read.py 21850 2013-04-02 16:01:50Z kulath $
 
 """
 Read classes for the GRAMPS databases.
@@ -709,6 +709,7 @@ class DbBsddbRead(DbReadBase, Callback):
         return self.get_from_handle(handle, Tag, self.tag_map)
 
     def __get_obj_from_gramps_id(self, val, tbl, class_, prim_tbl):
+        if isinstance(tbl, dict): return None ## trying to get object too early
         try:
             data = tbl.get(str(val), txn=self.txn)
             if data is not None:
@@ -1751,7 +1752,7 @@ class DbBsddbRead(DbReadBase, Callback):
         filepath = os.path.join(self.path, "name.txt")
         try:
             name_file = open(filepath, "r")
-            name = name_file.read()
+            name = name_file.readline().strip()
             name_file.close()
         except (OSError, IOError), msg:
             self.__log_error()
