@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: write.py 20010 2012-07-16 17:53:43Z kulath $
+# $Id: write.py 22241 2013-05-10 14:29:47Z kulath $
 
 """
 Provide the Berkeley DB (DbBsddb) database backend for GRAMPS.
@@ -40,7 +40,7 @@ import locale
 import bisect
 from functools import wraps
 import logging
-from sys import maxint
+from sys import maxint, getfilesystemencoding, version_info
 
 from gen.ggettext import gettext as _
 import config
@@ -59,7 +59,7 @@ from gen.lib import (GenderStats, Person, Family, Event, Place, Source,
 from gen.db import (DbBsddbRead, DbWriteBase, BSDDBTxn, 
                     DbTxn, BsddbBaseCursor, BsddbDowngradeError, DbVersionError,
                     DbEnvironmentError, DbUpgradeRequiredError, find_surname,
-                    find_surname_name, DbUndoBSDDB as DbUndo)
+                    find_surname_name, DbUndoBSDDB as DbUndo, exceptions)
 from gen.db.dbconst import *
 from gen.utils.callback import Callback
 from gen.updatecallback import UpdateCallback
@@ -232,6 +232,7 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
         self.has_changed = False
         self.brief_name = None
         self.update_env_version = False
+        self.update_python_version = False
 
     def catch_db_error(func):
         """
@@ -357,34 +358,149 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
             with BSDDBTxn(self.env, self.metadata) as txn:
                 txn.put('mediapath', path)            
 
-    def __check_bdb_version(self, name):
-        """Older version of Berkeley DB can't read data created by a newer
-        version."""
+    def __make_zip_backup(self, dirname):
+        import zipfile
+        title = self.get_dbname()
+        
+        if not os.access(dirname, os.W_OK):
+            _LOG.warning("Can't write technical DB backup for %s" % title)
+            return
+        (grampsdb_path, db_code) = os.path.split(dirname)
+        dotgramps_path = os.path.dirname(grampsdb_path)
+        zipname = title + time.strftime("_%Y-%m-%d_%H-%M-%S") + ".zip"
+        zipname = zipname.encode(getfilesystemencoding())
+        zippath = os.path.join(dotgramps_path, zipname)
+        myzip = zipfile.ZipFile(zippath, 'w')
+        for filename in os.listdir(dirname):
+            pathname = os.path.join(dirname, filename)
+            myzip.write(pathname, os.path.join(db_code, filename))
+        myzip.close()
+        _LOG.warning("If upgrade and loading the Family Tree works, you can "
+                     "delete the zip file at %s" %
+                     zippath)
+    
+    def __check_bdb_version(self, name, force_bsddb_upgrade=False,
+                            force_bsddb_downgrade=False):
+        """
+        Older version of Berkeley DB can't read data created by a newer
+        version.
+        name: Directory path of the database files
+        force_bsddb_upgrade: whether the user has requested that the database be
+        upgraded
+        """
         bdb_version = db.version()
-        env_version = (0, 0, 0)
         versionpath = os.path.join(self.path, BDBVERSFN)
-        try:
+        # Compare the current version of the database (bsddb_version) with the
+        # version of the database code (env_version). If it is a downgrade,
+        # raise an exception because we can't do anything. If they are the same,
+        # return. If it is an upgrade, raise an exception unless  the user has
+        # already told us we can upgrade.
+        if os.path.isfile(versionpath):
             with open(versionpath, "r") as version_file:
-                env_version = version_file.read().strip()
-                env_version = tuple(map(int, env_version[1:-1].split(', ')))
-        except:
-            # Just assume that the Berkeley DB version is OK.
-            pass
-        if (env_version[0] > bdb_version[0]) or \
+                bsddb_version = version_file.read().strip()
+                env_version = tuple(map(int, bsddb_version[1:-1].split(', ')))
+        else:
+            # bsddb version is unknown
+            env_version = "Unknown"
+#        _LOG.debug("db version %s, program version %s" % (bsddb_version, bdb_version))
+
+        if env_version == "Unknown" or \
+            (env_version[0] < bdb_version[0]) or \
+            (env_version[0] == bdb_version[0] and
+             env_version[1] < bdb_version[1]) or \
+            (env_version[0] == bdb_version[0] and
+             env_version[1] == bdb_version[1] and
+             env_version[2] < bdb_version[2]):
+            # an upgrade is needed
+            if not force_bsddb_upgrade:
+                _LOG.debug("Bsddb upgrade required from %s to %s" %
+                           (bsddb_version, str(bdb_version)))
+                clear_lock_file(name)
+                raise exceptions.BsddbUpgradeRequiredError(bsddb_version,
+                                                           str(bdb_version))
+            if not self.readonly:
+                _LOG.warning("Bsddb upgrade requested from %s to %s" %
+                             (bsddb_version, str(bdb_version)))
+                self.update_env_version = True
+            # Make a backup of the database files anyway 
+            self.__make_zip_backup(name)   
+        elif (env_version[0] > bdb_version[0]) or \
             (env_version[0] == bdb_version[0] and
              env_version[1] > bdb_version[1]):
             clear_lock_file(name)
             raise BsddbDowngradeError(env_version, bdb_version)
-        elif env_version != bdb_version and not self.readonly:
-            self.update_env_version = True
+        elif (env_version[0] == bdb_version[0] and
+             env_version[1] == bdb_version[1] and
+             env_version[2] > bdb_version[2]):
+            # A down-grade may be possible
+            if not force_bsddb_downgrade:
+                _LOG.debug("Bsddb downgrade required from %s to %s" %
+                           (bsddb_version, str(bdb_version)))
+                clear_lock_file(name)
+                raise exceptions.BsddbDowngradeRequiredError(bsddb_version,
+                                                           str(bdb_version))
+            # Try to do a down-grade
+            if not self.readonly:
+                _LOG.warning("Bsddb downgrade requested from %s to %s" %
+                             (bsddb_version, str(bdb_version)))
+                self.update_env_version = True
+            # Make a backup of the database files anyway 
+            self.__make_zip_backup(name)   
+        elif env_version == bdb_version:
+            # Bsddb version is OK
+            pass
+        else:
+            # This can't happen
+            raise "Comparison between Bsddb version failed"
 
+    def __check_python_version(self, name, force_python_upgrade=False):
+        """
+        The 'pickle' format (may) change with each Python version, see
+        http://docs.python.org/3.2/library/pickle.html#pickle. Code commits
+        21777 and 21778 ensure that when going from python2 to python3, the old
+        format can be read. However, once the data has been written in the
+        python3 format, it will not be possible to go back to pyton2. This check
+        test whether we are changing python versions. If going from 2 to 3 it
+        warns the user, and allows it if he confirms. When going from 3 to 3, an
+        error is raised. Because code for python2 did not write the Python
+        version file, if the file is absent, python2 is assumed.
+        """
+        current_python_version = version_info[0]
+        versionpath = os.path.join(self.path, "pythonversion.txt")
+        if os.path.isfile(versionpath):
+            with open(versionpath, "r") as version_file:
+                db_python_version = int(version_file.read().strip())
+        else:
+            db_python_version = 2
+            
+        if db_python_version == 3 and current_python_version == 2:
+            clear_lock_file(name)
+            raise exceptions.PythonDowngradeError(db_python_version,
+                                                  current_python_version)
+        elif db_python_version == 2 and current_python_version > 2:
+            if not force_python_upgrade:
+                _LOG.debug("Python upgrade required from %s to %s" %
+                           (db_python_version, current_python_version))
+                clear_lock_file(name)
+                raise exceptions.PythonUpgradeRequiredError(db_python_version,
+                                                        current_python_version)
+            # Try to do an upgrade
+            if not self.readonly:
+                _LOG.warning("Python upgrade requested from %s to %s" %
+                             (db_python_version, current_python_version))
+                self.update_python_version = True
+            # Make a backup of the database files anyway 
+            self.__make_zip_backup(name)
+        elif db_python_version == 2 and current_python_version == 2:
+            pass
+    
     @catch_db_error
     def version_supported(self):
         dbversion = self.metadata.get('version', default=0)
         return ((dbversion <= _DBVERSION) and (dbversion >= _MINVERSION))
 
     @catch_db_error
-    def need_upgrade(self):
+    def need_schema_upgrade(self):
         dbversion = self.metadata.get('version', default=0)
         return not self.readonly and dbversion < _DBVERSION
 
@@ -410,7 +526,9 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
         return False
 
     @catch_db_error
-    def load(self, name, callback, mode=DBMODE_W, upgrade=False):
+    def load(self, name, callback, mode=DBMODE_W, force_schema_upgrade=False,
+             force_bsddb_upgrade=False, force_bsddb_downgrade=False,
+             force_python_upgrade=False):
 
         if self.__check_readonly(name):
             mode = DBMODE_R
@@ -430,7 +548,14 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
         self.path = self.full_name
         self.brief_name = os.path.basename(name)
 
-        self.__check_bdb_version(name)
+        # If we re-enter load with force_python_upgrade True, then we have
+        # already checked the bsddb version, and then checked python version,
+        # and are agreeing on the upgrade
+        if not force_python_upgrade:
+            self.__check_bdb_version(name, force_bsddb_upgrade,
+                                     force_bsddb_downgrade)
+        
+        self.__check_python_version(name, force_python_upgrade)
 
         # Set up database environment
         self.env = db.DBEnv()
@@ -452,8 +577,8 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
         
         # The DB_PRIVATE flag must go if we ever move to multi-user setup
         env_flags = db.DB_CREATE | db.DB_PRIVATE |\
-                    db.DB_INIT_MPOOL | db.DB_INIT_LOCK |\
-                    db.DB_INIT_LOG | db.DB_INIT_TXN | db.DB_THREAD
+                    db.DB_INIT_MPOOL |\
+                    db.DB_INIT_LOG | db.DB_INIT_TXN
 
         # As opposed to before, we always try recovery on databases
         env_flags |= db.DB_RECOVER
@@ -482,8 +607,9 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
         # If we cannot work with this DB version,
         # it makes no sense to go further
         if not self.version_supported():
+            tree_vers = self.metadata.get(b'version', default=0)
             self.__close_early()
-            raise DbVersionError()
+            raise DbVersionError(tree_vers, _MINVERSION, _DBVERSION)
 
         self.__load_metadata()
         gstats = self.metadata.get('gender_stats', default=None)
@@ -530,17 +656,36 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
         self.name_group = self.__open_db(self.full_name, NAME_GROUP,
                               db.DB_HASH, db.DB_DUP)
 
+        # We have now successfully opened the database, so if the BSDDB version
+        # has changed, we update the DBSDB version file. 
+        
+        if self.update_env_version:
+            versionpath = os.path.join(name, BDBVERSFN)
+            with open(versionpath, "w") as version_file:
+                version_file.write(str(db.version()))
+            _LOG.debug("Updated BDBVERSFN file to %s" % str(db.version()))
+
+        if self.update_python_version:
+            versionpath = os.path.join(name, "pythonversion.txt")
+            with open(versionpath, "w") as version_file:
+                version_file.write(str(version_info[0]))
+            _LOG.debug("Updated python version file to %s" % str(version_info[0]))
+            
         # Here we take care of any changes in the tables related to new code.
         # If secondary indices change, then they should removed
         # or rebuilt by upgrade as well. In any case, the
         # self.secondary_connected flag should be set accordingly.
-        if self.need_upgrade():
-            if upgrade == True:
+        if self.need_schema_upgrade():
+            oldschema = self.metadata.get('version', default=0)
+            newschema = _DBVERSION
+            _LOG.debug("Schema upgrade required from %s to %s" %
+                       (oldschema, newschema))
+            if force_schema_upgrade == True:
                 self.gramps_upgrade(callback)
             else:
                 self.__close_early()
                 clear_lock_file(name)
-                raise DbUpgradeRequiredError()
+                raise DbUpgradeRequiredError(oldschema, newschema)
 
         if callback:
             callback(50)
@@ -1073,11 +1218,6 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
             self.transaction_abort(self.transaction)
         self.env.txn_checkpoint()
 
-        lockstats = self.env.lock_stat()
-        _LOG.debug("lock occupancy: %d%%, locked object occupancy: %d%%" % (
-                round(lockstats['maxnlocks']*100/lockstats['maxlocks']),
-                round(lockstats['maxnobjects']*100/lockstats['maxobjects'])))
-
         self.__close_metadata()
         self.name_group.close()
         self.surnames.close()
@@ -1147,15 +1287,6 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
         self.undo_history_callback = None
         self.undodb = None
 
-        if self.update_env_version:
-            versionpath = os.path.join(self.path, BDBVERSFN)
-            try:
-                with open(versionpath, "w") as version_file:
-                    version_file.write(str(db.version()))
-            except:
-                # Storing the version of Berkeley Db is not really vital.
-                pass
-
         try:
             clear_lock_file(self.get_save_path())
         except IOError:
@@ -1964,8 +2095,8 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
 
         # The DB_PRIVATE flag must go if we ever move to multi-user setup
         env_flags = db.DB_CREATE | db.DB_PRIVATE |\
-                    db.DB_INIT_MPOOL | db.DB_INIT_LOCK |\
-                    db.DB_INIT_LOG | db.DB_INIT_TXN | db.DB_THREAD
+                    db.DB_INIT_MPOOL |\
+                    db.DB_INIT_LOG | db.DB_INIT_TXN
 
         # As opposed to before, we always try recovery on databases
         env_flags |= db.DB_RECOVER
@@ -1978,9 +2109,20 @@ class DbBsddb(DbBsddbRead, DbWriteBase, UpdateCallback):
 
         self.metadata  = self.__open_shelf(full_name, META)
         
+        _LOG.debug("Write schema version %s" % _DBVERSION)
         with BSDDBTxn(self.env, self.metadata) as txn:
             txn.put('version', _DBVERSION)
         
+        versionpath = os.path.join(name, BDBVERSFN)
+        _LOG.debug("Write bsddb version %s" % str(db.version()))
+        with open(versionpath, "w") as version_file:
+            version_file.write(str(db.version()))
+
+        versionpath = os.path.join(name, "pythonversion.txt")
+        _LOG.debug("Write python version file to %s" % str(version_info[0]))
+        with open(versionpath, "w") as version_file:
+            version_file.write(str(version_info[0]))
+
         self.metadata.close()
         self.env.close()
   
