@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: graphdoc.py 20446 2012-09-25 16:57:16Z ldnp $
+# $Id: graphdoc.py 21632 2013-03-12 16:33:50Z nick-h $
 
 #------------------------------------------------------------------------
 #
@@ -78,9 +78,9 @@ _PAGEDIR = [ { 'name' : _("Bottom, left"),                  'value' :"BL" },
              { 'name' : _("Left, bottom"),                  'value' :"LB" },
              { 'name' : _("Left, top"),                     'value' :"LT" } ]
 
-_RATIO = [ { 'name' : _("Minimal size"),                'value': "compress" },
-           { 'name' : _("Fill the given area"),         'value': "fill"      },
-           { 'name' : _("Use optimal number of pages"), 'value': "expand"    } ]
+_RATIO = [ { 'name' : _("Compress to minimal size"),    'value': "compress" },
+           { 'name' : _("Fill the given area"),         'value': "fill"     },
+           { 'name' : _("Expand uniformly"),            'value': "expand"   } ]
 
 _NOTELOC = [ { 'name' : _("Top"),    'value' : "t" },
              { 'name' : _("Bottom"), 'value' : "b" }]
@@ -116,6 +116,7 @@ class GVOptions():
         self.h_pages    = None
         self.v_pages    = None
         self.page_dir   = None
+        self.dpi        = None
 
     def add_menu_options(self, menu):
         """
@@ -191,16 +192,29 @@ class GVOptions():
         aspect_ratio = EnumeratedListOption(_("Aspect ratio"), "fill")
         for item in _RATIO:
             aspect_ratio.add_item(item["value"], item["name"])
-        aspect_ratio.set_help(_("Affects greatly how the graph is layed out "
-                                "on the page."))
+        help_text = _('Affects node spacing and scaling of the graph.\n'
+            'If the graph is smaller than the print area:\n'
+            '  Compress will not change the node spacing. \n'
+            '  Fill will increase the node spacing to fit the print area in '
+            'both width and height.\n'
+            '  Expand will increase the node spacing uniformly to preserve '
+            'the aspect ratio.\n'
+            'If the graph is larger than the print area:\n'
+            '  Compress will shrink the graph to achieve tight packing at the '
+            'expense of symmetry.\n'
+            '  Fill will shrink the graph to fit the print area after first '
+            'increasing the node spacing.\n'
+            '  Expand will shrink the graph uniformly to fit the print area.')
+        aspect_ratio.set_help(help_text)
         menu.add_option(category, "ratio", aspect_ratio)
 
         dpi = NumberOption(_("DPI"), 75, 20, 1200)
         dpi.set_help(_( "Dots per inch.  When creating images such as "
                         ".gif or .png files for the web, try numbers "
-                        "such as 100 or 300 DPI.  When creating PostScript "
-                        "or PDF files, use 72 DPI."))
+                        "such as 100 or 300 DPI.  PostScript and PDF files "
+                        "always use 72 DPI."))
         menu.add_option(category, "dpi", dpi)
+        self.dpi = dpi
 
         nodesep = NumberOption(_("Node spacing"), 0.20, 0.01, 5.00, 0.01)
         nodesep.set_help(_( "The minimum amount of free space, in inches, "
