@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: filter.py 21796 2013-03-28 18:28:44Z kulath $
 
 """
 Proxy class for the GRAMPS databases. Apply filter
@@ -139,9 +139,22 @@ class FilterProxyDb(ProxyDbBase):
         If no such Source exists, None is returned.
         """
         source = self.db.get_source_from_handle(handle)
-        # Filter notes out
 
-        self.sanitize_notebase(source)
+        if source:
+            # Filter notes out
+            self.sanitize_notebase(source)
+            
+            media_ref_list = source.get_media_list()
+            for media_ref in media_ref_list:
+                self.sanitize_notebase(media_ref)
+                attributes = media_ref.get_attribute_list()
+                for attribute in attributes:
+                    self.sanitize_notebase(attribute)
+            
+            repo_ref_list = source.get_reporef_list()
+            for repo_ref in repo_ref_list:
+                self.sanitize_notebase(repo_ref)
+
         return source
 
     def get_citation_from_handle(self, handle):
@@ -151,7 +164,6 @@ class FilterProxyDb(ProxyDbBase):
         """
         citation = self.db.get_citation_from_handle(handle)
         # Filter notes out
-
         self.sanitize_notebase(citation)
         return citation
 
@@ -161,8 +173,15 @@ class FilterProxyDb(ProxyDbBase):
         If no such Object exists, None is returned.
         """
         media = self.db.get_object_from_handle(handle)
-        # Filter notes out
-        self.sanitize_notebase(media)
+
+        if media:
+            # Filter notes out
+            self.sanitize_notebase(media)
+            
+            attributes = media.get_attribute_list()
+            for attr in attributes:
+                self.sanitize_notebase(attr)
+
         return media
 
     def get_place_from_handle(self, handle):
@@ -171,8 +190,18 @@ class FilterProxyDb(ProxyDbBase):
         If no such Place exists, None is returned.
         """
         place = self.db.get_place_from_handle(handle)
-        # Filter notes out
-        self.sanitize_notebase(place)
+        
+        if place:
+            # Filter notes out
+            self.sanitize_notebase(place)
+            
+            media_ref_list = place.get_media_list()
+            for media_ref in media_ref_list:
+                self.sanitize_notebase(media_ref)
+                attributes = media_ref.get_attribute_list()
+                for attribute in attributes:
+                    self.sanitize_notebase(attribute)
+
         return place
 
     def get_event_from_handle(self, handle):
@@ -212,7 +241,33 @@ class FilterProxyDb(ProxyDbBase):
             family.set_child_ref_list(clist)
             
             # Filter notes out
+            for cref in clist:
+                self.sanitize_notebase(cref)
+            
             self.sanitize_notebase(family)
+            
+            attributes = family.get_attribute_list()
+            for attr in attributes:
+                self.sanitize_notebase(attr)
+
+            event_ref_list = family.get_event_ref_list()
+            for event_ref in event_ref_list:
+                self.sanitize_notebase(event_ref)
+                attributes = event_ref.get_attribute_list()
+                for attribute in attributes:
+                    self.sanitize_notebase(attribute)
+                
+            media_ref_list = family.get_media_list()
+            for media_ref in media_ref_list:
+                self.sanitize_notebase(media_ref)
+                attributes = media_ref.get_attribute_list()
+                for attribute in attributes:
+                    self.sanitize_notebase(attribute)
+
+            lds_ord_list = family.get_lds_ord_list()
+            for lds_ord in lds_ord_list:
+                self.sanitize_notebase(lds_ord)
+
             return family
         else:
             return None
@@ -246,6 +301,8 @@ class FilterProxyDb(ProxyDbBase):
         person = self.db.get_person_from_gramps_id(val)
         if person:
             return self.get_person_from_handle(person.get_handle())
+        else:
+            return None
 
     def get_family_from_gramps_id(self, val):
         """
@@ -255,6 +312,8 @@ class FilterProxyDb(ProxyDbBase):
         family = self.db.get_family_from_gramps_id(val)
         if family:
             return self.get_family_from_handle(family.get_handle())
+        else:
+            return None
 
     def get_event_from_gramps_id(self, val):
         """
@@ -264,6 +323,8 @@ class FilterProxyDb(ProxyDbBase):
         event = self.db.get_event_from_gramps_id(val)
         if event:
             return self.get_event_from_handle(event.get_handle())
+        else:
+            return None
 
     def get_place_from_gramps_id(self, val):
         """
@@ -273,6 +334,8 @@ class FilterProxyDb(ProxyDbBase):
         place = self.db.get_place_from_gramps_id(val)
         if place:
             return self.get_place_from_handle(place.get_handle())
+        else:
+            return None
 
     def get_source_from_gramps_id(self, val):
         """
@@ -282,6 +345,8 @@ class FilterProxyDb(ProxyDbBase):
         source = self.db.get_source_from_gramps_id(val)
         if source:
             return self.get_source_from_handle(source.get_handle())
+        else:
+            return None
 
     def get_citation_from_gramps_id(self, val):
         """
@@ -291,6 +356,8 @@ class FilterProxyDb(ProxyDbBase):
         citation = self.db.get_citation_from_gramps_id(val)
         if citation:
             return self.get_citation_from_handle(citation.get_handle())
+        else:
+            return None
 
     def get_object_from_gramps_id(self, val):
         """
@@ -300,6 +367,8 @@ class FilterProxyDb(ProxyDbBase):
         media = self.db.get_object_from_gramps_id(val)
         if media:
             return self.get_object_from_handle(media.get_handle())
+        else:
+            return None
 
     def get_repository_from_gramps_id(self, val):
         """
@@ -309,6 +378,8 @@ class FilterProxyDb(ProxyDbBase):
         repository = self.db.get_repository_from_gramps_id(val)
         if repository:
             return self.get_repository_from_handle(repository.get_handle())
+        else:
+            return None
 
     def get_note_from_gramps_id(self, val):
         """
@@ -318,6 +389,8 @@ class FilterProxyDb(ProxyDbBase):
         note = self.db.get_note_from_gramps_id(val)
         if note:
             return self.get_note_from_handle(note.get_handle())
+        else:
+            return None
 
     def get_person_handles(self, sort_handles=False):
         """
@@ -500,3 +573,29 @@ class FilterProxyDb(ProxyDbBase):
                 self.sanitize_notebase(name)
 
             self.sanitize_addressbase(person)
+
+            attributes = person.get_attribute_list()
+            for attr in attributes:
+                self.sanitize_notebase(attr)
+
+            event_ref_list = person.get_event_ref_list()
+            for event_ref in event_ref_list:
+                self.sanitize_notebase(event_ref)
+                attributes = event_ref.get_attribute_list()
+                for attribute in attributes:
+                    self.sanitize_notebase(attribute)
+
+            media_ref_list = person.get_media_list()
+            for media_ref in media_ref_list:
+                self.sanitize_notebase(media_ref)
+                attributes = media_ref.get_attribute_list()
+                for attribute in attributes:
+                    self.sanitize_notebase(attribute)
+
+            lds_ord_list = person.get_lds_ord_list()
+            for lds_ord in lds_ord_list:
+                self.sanitize_notebase(lds_ord)
+
+            person_ref_list = person.get_person_ref_list()
+            for person_ref in person_ref_list:
+                self.sanitize_notebase(person_ref)
