@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: referencedbyselection.py 21802 2013-03-28 23:31:58Z kulath $
 
 """
 Proxy class for the GRAMPS databases. Returns objects which are
@@ -232,9 +232,10 @@ class ReferencedBySelectionProxyDb(ProxyDbBase):
         self.process_attributes(event)
 
         place_handle = event.get_place_handle()
-        place = self.db.get_place_from_handle(place_handle)
-        if place:
-            self.process_place(place)
+        if place_handle:
+            place = self.db.get_place_from_handle(place_handle)
+            if place:
+                self.process_place(place)
     
     def process_place(self, place):
         """
@@ -307,22 +308,29 @@ class ReferencedBySelectionProxyDb(ProxyDbBase):
         self.process_attributes(media)
         self.process_notes(media)
 
-    def process_notes(self, original_obj):
+    def process_note(self, note):
         """
         Follow the note object and find all of the primary objects
         that it references.
         """
+        if note is None or note.handle in self.referenced["Note"]:
+            return
+        self.referenced["Note"].add(note.handle)
+        for tag in note.text.get_tags():
+            if tag.name == 'Link':
+                if tag.value.startswith("gramps://"):
+                    obj_class, prop, value = tag.value[9:].split("/")
+                    if obj_class == "Media":         # bug6493
+                        obj_class = "MediaObject"
+                    if prop == "handle":
+                        self.process_object(obj_class, value)
+
+    def process_notes(self, original_obj):
+        """ Find all of the primary objects referred to """
         for note_handle in original_obj.get_note_list():
-            if note_handle and note_handle not in self.referenced["Note"]:
+            if note_handle:
                 note = self.db.get_note_from_handle(note_handle)
-                if note:
-                    self.referenced["Note"].add(note_handle)
-                    for tag in note.text.get_tags():
-                        if tag.name == 'Link':
-                            if tag.value.startswith("gramps://"):
-                                obj_class, prop, value = tag.value[9:].split("/")
-                                if prop == "handle":
-                                    self.process_object(obj_class, value)
+                self.process_note(note)
 
     # --------------------------------------------
 
@@ -396,9 +404,10 @@ class ReferencedBySelectionProxyDb(ProxyDbBase):
             self.process_family(fam)
 
         place_handle = lds_ord.get_place_handle()
-        place = self.db.get_place_from_handle(place_handle)
-        if place:
-            self.process_place(place)
+        if place_handle:
+            place = self.db.get_place_from_handle(place_handle)
+            if place:
+                self.process_place(place)
 
         self.process_citation_ref_list(lds_ord)
         self.process_notes(lds_ord)
