@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: gramps.py 20013 2012-07-16 22:54:43Z kulath $
+# $Id: gramps.py 21296 2013-02-04 19:15:22Z kulath $
 
 #-------------------------------------------------------------------------
 #
@@ -62,7 +62,9 @@ import constfunc
 """Setup basic logging support."""
 
 # Setup a formatter
-form = logging.Formatter(fmt="%(relativeCreated)d: %(levelname)s: %(filename)s: line %(lineno)d: %(message)s")
+form = logging.Formatter(fmt="%(asctime)s.%(msecs).03d: %(levelname)s: "
+                             "%(filename)s: line %(lineno)d: %(message)s",
+                         datefmt='%Y-%m-%d %H:%M:%S')
 
 # Create the log handlers
 if constfunc.win():
