@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: configure.py 20455 2012-09-27 09:18:34Z bmcage $
+# $Id: configure.py 22157 2013-05-04 06:06:16Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -219,6 +219,27 @@ class ConfigureDialog(ManagedWindow.ManagedWindow):
         """
         self.__config.set(constant, unicode(obj.get_text()))
 
+    def update_markup_entry(self, obj, constant):
+        """
+        :param obj: an object with get_text method 
+        :param constant: the config setting to which the text value must be 
+            saved
+        """
+        try:
+            obj.get_text() % 'test_markup'
+        except TypeError:
+            print("WARNING: ignoring invalid value for '%s'" % constant)
+            ErrorDialog(_("Invalid or incomplete format definition."), 
+            obj.get_text())
+            obj.set_text('<b>%s</b>')
+        except ValueError:
+            print("WARNING: ignoring invalid value for '%s'" % constant)
+            ErrorDialog(_("Invalid or incomplete format definition."),
+            obj.get_text())
+            obj.set_text('<b>%s</b>')
+        
+        self.__config.set(constant, unicode(obj.get_text()))
+
     def update_color(self, obj, constant, color_hex_label):
         color = obj.get_color()
         hexval = "#%02x%02x%02x" % (color.red/256, 
@@ -307,7 +328,7 @@ class ConfigureDialog(ManagedWindow.ManagedWindow):
         table.attach(hbox, 2, 3, index, index+1, yoptions=0)
 
     def add_entry(self, table, label, index, constant, callback=None,
-                  config=None):
+                  config=None, col_attach=0):
         if not config:
             config = self.__config
         if not callback:
@@ -316,12 +337,12 @@ class ConfigureDialog(ManagedWindow.ManagedWindow):
         entry = gtk.Entry()
         entry.set_text(config.get(constant))
         entry.connect('changed', callback, constant)
-        table.attach(lwidget, 0, 1, index, index+1, yoptions=0, 
+        table.attach(lwidget, col_attach, col_attach+1, index, index+1, yoptions=0, 
                      xoptions=gtk.FILL)
-        table.attach(entry, 1, 2, index, index+1, yoptions=0)
+        table.attach(entry, col_attach+1, col_attach+2, index, index+1, yoptions=0)
 
     def add_pos_int_entry(self, table, label, index, constant, callback=None,
-                          config=None, col_attach=1):
+                          config=None, col_attach=1, helptext=''):
         """ entry field for positive integers
         """
         if not config:
@@ -329,6 +350,7 @@ class ConfigureDialog(ManagedWindow.ManagedWindow):
         lwidget = BasicLabel("%s: " % label)
         entry = gtk.Entry()
         entry.set_text(str(config.get(constant)))
+        entry.set_tooltip_markup(helptext)
         if callback:
             entry.connect('changed', callback, constant)
         table.attach(lwidget, col_attach, col_attach+1, index, index+1,
@@ -1034,12 +1056,26 @@ class GrampsPreferences(ConfigureDialog):
                 6, 'behavior.avg-generation-gap', self.update_int_entry)
         self.add_pos_int_entry(table,
                 _('Markup for invalid date format'), 
-                7, 'preferences.invalid-date-format', self.update_entry)
+                7, 'preferences.invalid-date-format',
+                self.update_markup_entry,
+                helptext = _('Convenience markups are:\n'
+                '<b>&lt;b&gt;Bold&lt;/b&gt;</b>\n'
+                '<big>&lt;big&gt;Makes font relatively larger&lt;/big&gt;</big>\n'
+                '<i>&lt;i&gt;Italic&lt;/i&gt;</i>\n'
+                '<s>&lt;s&gt;Strikethrough&lt;/s&gt;</s>\n'
+                '<sub>&lt;sub&gt;Subscript&lt;/sub&gt;</sub>\n'
+                '<sup>&lt;sup&gt;Superscript&lt;/sup&gt;</sup>\n'
+                '<small>&lt;small&gt;Makes font relatively smaller&lt;/small&gt;</small>\n'
+                '<tt>&lt;tt&gt;Monospace font&lt;/tt&gt;</tt>\n'
+                '<u>&lt;u&gt;Underline&lt;/u&gt;</u>\n\n'
+                'For example: &lt;u&gt;&lt;b&gt;%s&lt;/b&gt;&lt;/u&gt;\n'
+                'will display <u><b>Underlined bold date</b></u>\n')
+                )
 
         return _('Dates'), table
         
     def add_behavior_panel(self, configdialog):
-        table = gtk.Table(3, 6)
+        table = gtk.Table(2, 8)
         table.set_border_width(12)
         table.set_col_spacings(6)
         table.set_row_spacings(6)
@@ -1097,16 +1133,18 @@ class GrampsPreferences(ConfigureDialog):
         table.attach(lwidget, 1, 2, 7, 8, yoptions=0)
         table.attach(self.whattype_box, 2, 3, 7, 8, yoptions=0)
 
+        self.add_entry(table, _('Where to check'), 8, 'behavior.addons-url', col_attach=1)
+
         checkbutton = gtk.CheckButton(
             _("Do not ask about previously notified addons"))
         checkbutton.set_active(config.get('behavior.do-not-show-previously-seen-updates'))
         checkbutton.connect("toggled", self.toggle_hide_previous_addons)
 
-        table.attach(checkbutton, 0, 3, 8, 9, yoptions=0)
+        table.attach(checkbutton, 1, 2, 9, 10, yoptions=0)
         button = gtk.Button(_("Check now"))
         button.connect("clicked", lambda obj: \
                   self.uistate.viewmanager.check_for_updates(force=True))
-        table.attach(button, 3, 4, 8, 9, yoptions=0)
+        table.attach(button, 3, 4, 9, 10, yoptions=0)
 
         return _('General'), table
 
