@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: backreflist.py 20427 2012-09-21 17:46:54Z kulath $
+# $Id: backreflist.py 21572 2013-03-07 08:14:27Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -172,7 +172,7 @@ class BackRefList(EmbeddedList):
                                  "edited, and opening a citation editor "
                                  "(which also allows the source "
                                  "to be edited), would create ambiguity "
-                                 "by opening two editor on the same source. "
+                                 "by opening two editors on the same source. "
                                  "\n\n"
                                  "To edit the citation, close the source "
                                  "editor and open an editor for the citation "
