@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: grampsbar.py 19753 2012-06-04 00:55:10Z jralls $
+# $Id: grampsbar.py 21335 2013-02-10 21:11:16Z paul-franklin $
 
 """
 Module that implements the sidebar and bottombar fuctionality.
@@ -126,7 +126,10 @@ class GrampsBar(gtk.Notebook):
         filename = self.configfile
         if filename and os.path.exists(filename):
             cp = ConfigParser.ConfigParser()
-            cp.read(filename)
+            try:
+                cp.read(filename)
+            except:
+                pass
             for sec in cp.sections():
                 if sec == "Bar Options":
                     if "visible" in cp.options(sec):
