@@ -21,7 +21,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id$
+# $Id: _graphvizreportdialog.py 21632 2013-03-12 16:33:50Z nick-h $
 
 #------------------------------------------------------------------------
 #
@@ -115,6 +115,7 @@ class GraphvizReportDialog(ReportDialog):
         more information."""
         self.category = CATEGORY_GRAPHVIZ
         self.__gvoptions = graphdoc.GVOptions()
+        self.dbname = dbstate.db.get_dbname()
         ReportDialog.__init__(self, dbstate, uistate, opt,
                               name, translated_name)
         
@@ -165,7 +166,8 @@ class GraphvizReportDialog(ReportDialog):
             ext = ""
         else:
             spath = self.get_default_directory()
-            base = "%s%s" % (self.raw_name, ext)
+            default_name = self.dbname + "_" + self.raw_name
+            base = "%s%s" % (default_name, ext) # "ext" already has a dot
             spath = os.path.normpath(os.path.join(spath, base))
             self.target_fileentry.set_filename(spath)
                 
@@ -206,6 +208,24 @@ class GraphvizReportDialog(ReportDialog):
             fname = spath
         self.target_fileentry.set_filename(fname)
             
+        format_str = obj.get_format_str()
+        if format_str in ['gvpdf', 'gspdf', 'ps']:
+            # Always use 72 DPI for PostScript and PDF files.
+            self.__gvoptions.dpi.set_value(72)
+            self.__gvoptions.dpi.set_available(False)
+        else:
+            self.__gvoptions.dpi.set_available(True)
+
+        if format_str in ['gspdf', 'dot']:
+            # Multiple pages only valid for dot and PDF via GhostsScript.
+            self.__gvoptions.h_pages.set_available(True)
+            self.__gvoptions.v_pages.set_available(True)
+        else:
+            self.__gvoptions.h_pages.set_value(1)
+            self.__gvoptions.v_pages.set_value(1)
+            self.__gvoptions.h_pages.set_available(False)
+            self.__gvoptions.v_pages.set_available(False)
+
     def make_document(self):
         """Create a document of the type requested by the user.
         """
