@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: utils.py 19753 2012-06-04 00:55:10Z jralls $
+# $Id: utils.py 21664 2013-03-16 21:47:20Z nick-h $
 
 """
 Utility functions that depend on GUI components or for GUI components
@@ -96,6 +96,10 @@ class CLIDialog:
         pass
     def set_size_request(self, width, height):
         pass
+    def set_transient_for(self, window):
+        pass
+    def set_modal(self, flag):
+        pass
     def show_all(self):
         pass
     def destroy(self):
@@ -128,7 +132,7 @@ class ProgressMeter(object):
     MODE_ACTIVITY = 1
 
     def __init__(self, title, header='', can_cancel=False,
-                 cancel_callback=None, message_area=False):
+                 cancel_callback=None, message_area=False, parent=None):
         """
         Specify the title and the current pass header.
         """
@@ -158,6 +162,9 @@ class ProgressMeter(object):
         self.__dialog.vbox.set_spacing(10)
         self.__dialog.vbox.set_border_width(24)
         self.__dialog.set_size_request(400, 125)
+        if parent:
+            self.__dialog.set_transient_for(parent)
+            self.__dialog.set_modal(True)
 
         tlbl = gtk.Label('<span size="larger" weight="bold">%s</span>' % title)
         tlbl.set_use_markup(True)
