@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # gui/views/treemodels/treebasemodel.py
-# $Id$
+# $Id: treebasemodel.py 21174 2013-01-20 15:10:26Z kulath $
 #
 
 """
@@ -88,7 +88,7 @@ class Node(object):
     def __init__(self, ref, parent, sortkey, handle, secondary):
         self.name = sortkey
         if sortkey:
-            self.sortkey = map(conv_unicode_tosrtkey_ongtk, sortkey)
+            self.sortkey = conv_unicode_tosrtkey_ongtk(sortkey)
         else:
             self.sortkey = None
         self.ref = ref
