@@ -28,7 +28,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: LaTeXDoc.py 19953 2012-07-05 13:54:01Z paul-franklin $
+# $Id: LaTeXDoc.py 21602 2013-03-10 19:29:02Z paul-franklin $
 
 """LaTeX document generator"""
 
@@ -48,7 +48,7 @@ import re, os, sys
 #------------------------------------------------------------------------
 from gen.plug.docgen import BaseDoc, TextDoc, PAPER_LANDSCAPE, FONT_SANS_SERIF, URL_PATTERN
 from gen.plug.docbackend import DocBackend
-import Image
+from PIL import Image
 import Errors
 import Utils
 
@@ -86,12 +86,12 @@ _LATEX_TEMPLATE = '''%
 % when utf8 is specified as an option to the inputenc
 % package. This package is included by default in some
 % installations, but not in others, so we do not make it
-% the default.  Uncomment the second line if you wish to use it
+% the default.  Uncomment the first line if you wish to use it
 % (If you do not have ucs.sty, you may obtain it from
 %  http://www.tug.org/tex-archive/macros/latex/contrib/supported/unicode/)
 %
-\\usepackage[latin1]{inputenc}%
-%\\usepackage[latin1,utf8]{inputenc}%
+%\\usepackage[latin1]{inputenc}%
+\\usepackage[latin1,utf8]{inputenc}%
 \\usepackage{graphicx}% Extended graphics support
 \\usepackage{longtable}% For multi-page tables
 \\usepackage{calc}% For some calculations
