@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DescendTree.py 19933 2012-06-28 15:41:55Z ander882 $
+# $Id: DescendTree.py 21927 2013-04-08 15:08:31Z paul-franklin $
 
 """
 Reports/Graphical Reports/Familial Tree
@@ -374,6 +374,7 @@ class RecurseDown:
         self.inlc_marr = gui.get_val("inc_marr")
         if not self.max_spouses:
             self.inlc_marr = False
+        self.spouse_indent = gui.get_val('ind_spouse')
         
         #is the option even available?
         self.bold_direct = gui.get_val('bolddirect')
@@ -427,7 +428,10 @@ class RecurseDown:
         if box.level[1] == 0:
             self.__last_direct[level] = box
             
-        box.x_cm = self.canvas.report_opts.spouse_offset * box.level[1]
+        if self.spouse_indent:
+            box.x_cm = self.canvas.report_opts.spouse_offset * box.level[1]
+        else:
+            box.x_cm = 0.0
         
         self.canvas.set_box_height_width(box)
         
