@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: libhtml.py 21346 2013-02-13 11:02:52Z kulath $
 
 #------------------------------------------------------------------------
 #
@@ -200,7 +200,7 @@ class Html(list):
         if title is not None: 
             head += (Html('title', title, inline=True, indent=True))
         if html5:
-            head += Html('meta', charset="utf-8", indent=True)
+            head += Html('meta', charset=encoding, indent=True)
         else:
             meta1 = 'http-equiv="content-type" content="text/html;charset=%s"'
             meta2 = 'http-equiv="Content-Style-Type" content="text/css"'
