@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: libtranslate.py 20544 2012-10-08 20:04:59Z romjerome $
+# $Id: libtranslate.py 22192 2013-05-07 14:21:18Z jralls $
 
 """
 Translator class for use by plugins.
@@ -144,7 +144,8 @@ class Translator:
         else:
             # fallback=True will cause the translator to use English if 
             # lang = "en" or if something goes wrong.
-            self.__trans = gettext.translation(TransUtils.get_localedomain(), 
+            self.__trans = gettext.translation(TransUtils.get_localedomain(),\
+                                               TransUtils.LOCALEDIR,
                                                languages=[lang], 
                                                fallback=True)
             val = config.get('preferences.date-format')
