@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: geography.py 20447 2012-09-25 16:59:16Z noirauds $
+# $Id: geography.py 20630 2012-11-05 08:20:53Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -983,7 +983,7 @@ class GeoGraphyView(osmGpsMap, NavigationView):
                         "The following places are similar : %(gid)s\n"
                         "Eiher you rename the places either you merge them."
                         "\n\n<b>I can't proceed your request</b>.\n") % {
-                                              'title': plce.get_title(),
+                                              'title': place.get_title(),
                                               'gid': gids}
                       )
             else:
