@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: pedigreeview.py 20248 2012-08-22 11:31:00Z bmcage $
+# $Id: pedigreeview.py 21642 2013-03-14 09:53:19Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -71,14 +71,7 @@ import gui.utils
 # Constants
 #
 #-------------------------------------------------------------------------
-if constfunc.is_quartz():
-    CAIRO_AVAILABLE = False
-else:
-    try:
-        import cairo
-        CAIRO_AVAILABLE = True
-    except ImportError:
-        CAIRO_AVAILABLE = False
+CAIRO_AVAILABLE = False
 
 _PERSON = "p"
 _BORN = _('short for born|b.')
