@@ -23,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: WebCal.py 21304 2013-02-05 18:06:02Z kulath $
 
 """
 Web Calendar generator.
@@ -51,6 +51,7 @@ log = logging.getLogger(".WebPage")
 import gen.lib
 import const
 import constfunc
+import config
 from gen.plug.report import Report
 from gen.plug.report import utils as ReportUtils
 from gen.plug.report import MenuReportOptions
@@ -248,6 +249,8 @@ class WebCalReport(Report):
                   "a different directory to store your generated "
                   "web pages."))
             self.warn_dir = False
+        config.set('paths.website-directory',
+                   os.path.dirname(self.html_dir) + os.sep)
 
     def add_day_item(self, text, year, month, day, event):
         """
@@ -1299,8 +1302,11 @@ class WebCalOptions(MenuReportOptions):
         """
         category_name = _("Report Options")
 
+        dbname = self.__db.get_dbname()
+        default_dir = dbname + "_WEBCAL"
         target = DestinationOption( _("Destination"),
-                                    os.path.join(const.USER_HOME, "WEBCAL"))
+                        os.path.join(config.get('paths.website-directory'),
+                                     default_dir))
         target.set_help( _("The destination directory for the web files"))
         target.set_directory_entry(True)
         menu.add_option(category_name, "target", target)
@@ -1418,7 +1424,9 @@ class WebCalOptions(MenuReportOptions):
         start_dow.set_help(_("Select the first day of the week for the calendar"))
         menu.add_option(category_name, "start_dow", start_dow)
 
-        home_link = StringOption(_('Home link'), '../../NAVWEB/index.html')
+        dbname = self.__db.get_dbname()
+        default_link = '../../' + dbname + "_NAVWEB/index.html"
+        home_link = StringOption(_('Home link'), default_link)
         home_link.set_help(_("The link to be included to direct the user to "
                          "the main page of the web site"))
         menu.add_option(category_name, "home_link", home_link)
@@ -1519,7 +1527,9 @@ class WebCalOptions(MenuReportOptions):
         menu.add_option(category_name, 'link_to_narweb', self.__links)  
         self.__links.connect('value-changed', self.__links_changed)
 
-        self.__prefix = StringOption(_('Link prefix'), "../../NAVWEB/")
+        dbname = self.__db.get_dbname()
+        default_prefix = '../../' + dbname + "_NAVWEB/"
+        self.__prefix = StringOption(_('Link prefix'), default_prefix)
         self.__prefix.set_help(_("A Prefix on the links to take you to "
                                  "Narrated Web Report"))
         menu.add_option(category_name, "prefix", self.__prefix)
